@@ -1,4 +1,4 @@
-/* (C) 2003 - 2005 by Marcin Wiacek www.mwiacek.com */
+/* (C) 2003 - 2007 by Marcin Wiacek www.mwiacek.com */
 
 #include <windows.h>
 #include <string.h>
@@ -94,7 +94,8 @@ GSM_Error GSM_Device_Serial::Open(char *Dev, char *Prot, char *Pho, char **Devic
 
 GSM_Error GSM_Device_Serial::Close()
 {
-		return GSM_Return_Error(GSM_ERR_NONE);
+	CloseHandle(Device);
+	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
 GSM_Error GSM_Device_Serial::Read(unsigned char *buf, int *len)
