@@ -158,15 +158,27 @@ BOOLEAN GSM_StateMachine::ReadCfgFile(INI_File *File)
 	return read;
 }
 
-void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
+void GSM_StateMachine::ReadCfg(int Set, GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
+	char		buff[40];
 	wchar_t		*value, x[200];
 	BOOLEAN		read;
 
 	read = ReadCfgFile(&File);
+	CFG->FileName[0] = 0;
+	if (read) sprintf(CFG->FileName,"%s",UnicodeToStringReturn(File.Info.ID.data()));
 
-	StringToUnicode("gammu",x);
+	if (Set == 1) {
+		sprintf(buff,"gammu");
+	} else {
+		sprintf(buff,"gammu%i",Set-1);
+	}
+	StringToUnicode(buff,x);
+
+	CFG->RSSLevel[0] = 0;
+	value = File.GetValue(x,StringToUnicodeReturn("rsslevel"));
+	if (value != NULL) sprintf(CFG->RSSLevel,"%s",UnicodeToStringReturn(value));
 
 	strcpy(CFG->Device,"com2:");
 #ifndef WIN32
@@ -187,15 +199,11 @@ void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 	value = File.GetValue(x,StringToUnicodeReturn("compatibility"));
 	if (value != NULL) sprintf(CFG->Compatibility,"%s",UnicodeToStringReturn(value));
 
-	CFG->RSSLevel[0] = 0;
-	value = File.GetValue(x,StringToUnicodeReturn("rsslevel"));
-	if (value != NULL) sprintf(CFG->RSSLevel,"%s",UnicodeToStringReturn(value));
-
 	strcpy(CFG->LogLevel,"nothing");
 	value = File.GetValue(x,StringToUnicodeReturn("logformat"));
 	if (value != NULL) sprintf(CFG->LogLevel,"%s",UnicodeToStringReturn(value));
 
-	strcpy(CFG->LogFile,"");
+	strcpy(CFG->LogFile,"log");
 	value = File.GetValue(x,StringToUnicodeReturn("logfile"));
 	if (value != NULL) sprintf(CFG->LogFile,"%s",UnicodeToStringReturn(value));
 
@@ -206,20 +214,30 @@ void GSM_StateMachine::ReadCfg(GSM_GPlusConfig *CFG)
 	strcpy(CFG->GetOnlineInfo,"no");
 	value = File.GetValue(x,StringToUnicodeReturn("usephonedb"));
 	if (value != NULL) sprintf(CFG->GetOnlineInfo,"%s",UnicodeToStringReturn(value));
+
+	sprintf(CFG->Name,"Set%i",Set);
+	value = File.GetValue(x,StringToUnicodeReturn("name"));
+	if (value != NULL) sprintf(CFG->Name,"%s",UnicodeToStringReturn(value));
 }
 
 /**
  * method for saving configuration file for HDD
  */
-void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
+void GSM_StateMachine::SaveCfg(int Set, GSM_GPlusConfig *CFG)
 {
 	INI_File	File;
-	wchar_t		x[200], x2[200];
+	char		buff[40];
+	wchar_t		x[200], x2[200];	
 	BOOLEAN		read;
 
 	read = ReadCfgFile(&File);
 
-	StringToUnicode("gammu",x);
+	if (Set == 1) {
+		sprintf(buff,"gammu");
+	} else {
+		sprintf(buff,"gammu%i",Set-1);
+	}
+	StringToUnicode(buff,x);
 
 	StringToUnicode("port",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Device));
@@ -245,10 +263,14 @@ void GSM_StateMachine::SaveCfg(GSM_GPlusConfig *CFG)
 	StringToUnicode("usephonedb",x2);
 	File.SetValue(x,x2,StringToUnicodeReturn(CFG->GetOnlineInfo));
 
+	StringToUnicode("name",x2);
+	File.SetValue(x,x2,StringToUnicodeReturn(CFG->Name));
+
 	if (read) {
 		File.SaveToDisk(UnicodeToStringReturn(File.Info.ID.data()));
 	} else {
 		File.SaveToDisk("gammurc");
+		sprintf(CFG->FileName,"gammurc");
 	}
 }
 
