@@ -18,8 +18,10 @@ typedef struct {
 	char		LogLevel[200];
 	char		SyncTime[200];
 	char		GetOnlineInfo[200];
+	char		Name[200];
 
 	char		RSSLevel[200];
+	char		FileName[1000];
 } GSM_GPlusConfig;
 
 /**
@@ -36,8 +38,8 @@ public:
         GSM_StateMachine(FILE *deb_file, char *FileName, bool enable);
         ~GSM_StateMachine();
 
-	void 			ReadCfg		(GSM_GPlusConfig *CFG);
-	void 			SaveCfg		(GSM_GPlusConfig *CFG);
+	void 			ReadCfg		(int Set, GSM_GPlusConfig *CFG);
+	void 			SaveCfg		(int Set, GSM_GPlusConfig *CFG);
 
 	GSM_Error 		Open		(GSM_GPlusConfig *CFG);
 
