@@ -39,6 +39,11 @@ GSM_Error GSM_Phone_N6510::GetNextNote(GSM_NoteEntry *Entry, BOOLEAN start, int
 	return GetNextCalendar3NoteToDo2(Entry, start, Current, Max, &Entry->Location, 0x02, ID_GetNote);
 }
 
+GSM_Error GSM_Phone_N6510::ReplyAddNote(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 {
 	int		     	Loc;
@@ -52,7 +57,7 @@ GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 		0x00, 0x00, 0x00, 0x00,
 		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm				*/
 		0x80, 0x00, 0x00,
-		0x01,				   	/* note icon			    */
+		0xA9,				   	/* note icon			    */
 		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm type			   */
 		0x00,				   	/* 0x02 or 0x00			 */
 		0x01,				   	/* note type			    */
@@ -60,7 +65,7 @@ GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* end date/time			*/
 		0x00, 0x00,			     	/* recurrance			   */
 		0x00, 0x00,			     	/* birth year			   */
-		0x20,				   	/* ToDo priority			*/
+		0x00,				   	/* ToDo priority			*/
 		0x00,				   	/* ToDo completed ?		     */
 		0x00, 0x00,			     	/* How many times repeat cal note or 0  */
 		0x00,
@@ -68,7 +73,7 @@ GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 		0x00,				   	/* phone length/meeting place	   */
 		0x00, 0x00, 0x00};
 	
-	error=GetFirstCalendarPos3(&Loc);
+	error=GetFirstCalendarPos3(&Loc,0x02);
 	if (error.Code!=GSM_ERR_NONE) return error;
 	req[8] = Loc/256;
 	req[9] = Loc%256;
@@ -83,12 +88,15 @@ GSM_Error GSM_Phone_N6510::AddNote(GSM_NoteEntry *Entry)
 
 	(*Debug)->Deb("SENT: Adding note\n");
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddNote+ID,Entry);
-//	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
 GSM_Error GSM_Phone_N6510::DeleteNote(GSM_NoteEntry *Entry)
 {
-	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	GSM_CalendarEntry Cal;
+
+	Cal.Location = Entry->Location;
+
+	return DCT34->DeleteCalendar(&Cal);
 }
 
 GSM_Error GSM_Phone_N6510::GetNextToDo(GSM_ToDoEntry *Entry, BOOLEAN start, int *Current, int *Max)
@@ -103,12 +111,17 @@ GSM_Error GSM_Phone_N6510::AddToDo(GSM_ToDoEntry *Entry)
 	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 
 	return AddToDo2(Entry);
-//	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 }
 
 GSM_Error GSM_Phone_N6510::DeleteToDo(GSM_ToDoEntry *Entry)
 {
-	return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+	GSM_CalendarEntry Cal;
+
+	if (!(*Phones)->Feature("todo6610")) return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+
+	Cal.Location = Entry->Location;
+
+	return DCT34->DeleteCalendar(&Cal);
 }
 
 // -------------------------------- method 3 ----------------------------------
@@ -541,11 +554,13 @@ GSM_Error GSM_Phone_N6510::ReplyGetFirstCalPos3(GSM_Protocol_Message *msg, Debug
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
 
-GSM_Error GSM_Phone_N6510::GetFirstCalendarPos3(int *Location)
+GSM_Error GSM_Phone_N6510::GetFirstCalendarPos3(int *Location,unsigned char type)
 {
 	unsigned char Buff[] = {NOKIA_FRAME1, 0x95, 0x00};
 
-	(*Debug)->Deb("SENT: Getting first free calendar note location (method 3)\n");
+	Buff[4] = type;
+	
+	(*Debug)->Deb("SENT: Getting first free calendar/todo/note location\n");
 	return Write(Buff, sizeof(Buff), 0x13, 2, ID_GetFirstCalendarPos+ID, Location);
 }
 
@@ -633,7 +648,7 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	if (error.Code!=GSM_ERR_NONE) return error;
 	req[21] = NoteID;
 
-	error=GetFirstCalendarPos3(&Loc);
+	error=GetFirstCalendarPos3(&Loc,0x00);
 	if (error.Code!=GSM_ERR_NONE) return error;
 	req[8] = Loc/256;
 	req[9] = Loc%256;
@@ -740,7 +755,128 @@ GSM_Error GSM_Phone_N6510::AddCalendar3(GSM_CalendarEntry *Entry)
 	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddCalendar+ID,Entry);
 }
 
+GSM_Error GSM_Phone_N6510::ReplyAddToDo2(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
+{
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 GSM_Error GSM_Phone_N6510::AddToDo2(GSM_ToDoEntry *Entry)
 {
-	return GSM_Return_Error(GSM_ERR_UNKNOWN);
+	int			Loc;
+	GSM_DateTime	    	DT;
+	time_t		  	timet1, timet2;
+	unsignedstring	  	Buffer,Buffer2;
+	GSM_ToDoSubEntry    	*SubEntry;
+	GSM_ToDoSubEntry    	*Text = NULL, *Priority = NULL, *Completed = NULL, *EndTime =NULL,*Alarm = NULL;
+	unsigned int	    	diff;
+	GSM_Error	       	error;
+	unsigned char	   	req[54] = {
+		NOKIA_FRAME1, 0x65,
+		0x01,				   	/* 0 = calendar, 1 = todo	       	*/
+		0x00, 0x00, 0x00,
+		0x00, 0x00,			     	/* location			     	*/
+		0x00, 0x00, 0x00, 0x00,
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm				*/
+		0x80, 0x00, 0x00,
+		0xA9,				   	/* note icon			   	*/
+		0xFF, 0xFF, 0xFF, 0xFF,		 	/* alarm type			   	*/
+		0x00,				   	/* 0x02 or 0x00			 	*/
+		0x01,				   	/* note type			    	*/
+		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* start date/time		      	*/
+		0x07, 0xD0, 0x01, 0x12, 0x0C, 0x00,     /* end date/time			*/
+		0x00, 0x00,			     	/* recurrance			   	*/
+		0x00, 0x00,			     	/* birth year			   	*/
+		0x20,				   	/* ToDo priority			*/
+		0x00,				   	/* ToDo completed ?		     	*/
+		0x00, 0x00,			     	/* How many times repeat cal note or 0  */
+		0x00,
+		0x00,				   	/* note text length		     	*/
+		0x00,				   	/* phone length/meeting place	   	*/
+		0x00, 0x00, 0x00};
+
+	error=GetFirstCalendarPos3(&Loc,0x01);
+	if (error.Code!=GSM_ERR_NONE) return error;
+	req[8] = Loc/256;
+	req[9] = Loc%256;
+
+	SubEntry = NULL;
+	while (Entry->GetNext(&SubEntry) == TRUE) {
+		switch (SubEntry->Type) {
+		case ToDo_Text_Text:
+			Text = SubEntry;
+			break;
+		case ToDo_Priority:
+			Priority = SubEntry;
+			break;
+		case ToDo_Bool_Completed:
+			Completed = SubEntry;
+			break;
+		case ToDo_DateTime_End:
+			EndTime = SubEntry;
+			break;
+		case ToDo_DateTime_ToneAlarm:
+		case ToDo_DateTime_SilentAlarm:
+			Alarm = SubEntry;
+			break;
+		}
+	}
+
+	if (Priority!=NULL) {
+		switch (Priority->Priority) {
+			case GSM_Priority_Low	: req[44] = 0x10; break;
+			case GSM_Priority_Medium: req[44] = 0x20; break;
+			case GSM_Priority_High	: req[44] = 0x30; break;
+			default: break;
+		}
+	}
+
+	if (Completed != NULL && Completed->BoolValue) req[45] = 0x01;
+
+	if (EndTime == NULL) {
+		GSM_GetCurrentDateTime(&DT);
+	} else {
+		memcpy(&DT,&EndTime->DT,sizeof(GSM_DateTime));
+	}
+	/*Start time*/
+	req[28]	= DT.Year / 256;
+	req[29]	= DT.Year % 256;
+	req[30]	= DT.Month;
+	req[31]	= DT.Day;
+	req[32]	= DT.Hour;
+	req[33]	= DT.Minute;
+	/*End time*/
+	req[34]	= DT.Year / 256;
+	req[35]	= DT.Year % 256;
+	req[36]	= DT.Month;
+	req[37]	= DT.Day;
+	req[38]	= DT.Hour;
+	req[39]	= DT.Minute;
+
+	if (Alarm != NULL) {
+		if (Alarm->Type == ToDo_DateTime_SilentAlarm)
+		{
+			req[22] = 0x00; req[23] = 0x00; req[24] = 0x00; req[25] = 0x00;
+		}
+		timet2   = GSMDateTime2TimeT(&DT);
+		timet1   = GSMDateTime2TimeT(&Alarm->DT); 
+		diff     = (timet2-timet1)/60;
+
+		req[14] = diff / (256*256*256);
+		req[15] = diff / (256*256);
+		req[16] = diff / 256;
+		req[17] = diff % 256;
+	}
+
+	if (Text != NULL) {
+		req[49] = UnicodeLength(Text->Text.data());
+		NokiaSetUnicodeString(Text->Text.data(),&Buffer);
+	}
+
+	Buffer.push_back(0x00);
+
+	Buffer2.append((const unsigned char*)req,sizeof(req));
+	Buffer2.append((const unsigned char*)Buffer.data(),Buffer.size());
+
+	(*Debug)->Deb("SENT: Adding todo (method 2)\n");
+	return Write((unsigned char *)Buffer2.data(), Buffer2.size(), 0x13, 4, ID_AddToDo+ID,Entry);
 }
