@@ -110,11 +110,16 @@ GSM_Error GSM_Phone_N6510::GetSMS2(GSM_SMSList *List, GSM_File *File)
 		}
 		SMS->UserData.append((const unsigned char *)(File->Buffer.data()+i+1),j);
 		i+=j;
+//		i+=SMS->TPUDL;
 		i+=11;
-		SMS->SetSMSCNumber(StringToUnicodeReturn((char *)(File->Buffer.data()+i)));
-		j=strlen((const char *)(File->Buffer.data()+i));
-		i+=j+4;
-		SMS->Name.append(NokiaGetUnicodeString(File->Buffer.data()+i),UnicodeLength(NokiaGetUnicodeString(File->Buffer.data()+i)));
+	(*Debug)->Deb("%02x %02x %02x\n",File->Buffer.data()[i],File->Buffer.data()[i+1],File->Buffer.data()[i+2]);
+	(*Debug)->Deb("%i %i\n",i,File->Buffer.size());
+		if (i<File->Buffer.size()) {
+			SMS->SetSMSCNumber(StringToUnicodeReturn((char *)(File->Buffer.data()+i)));
+			j=strlen((const char *)(File->Buffer.data()+i));
+			i+=j+4;
+			SMS->Name.append(NokiaGetUnicodeString(File->Buffer.data()+i),UnicodeLength(NokiaGetUnicodeString(File->Buffer.data()+i)));
+		}
 		break;
 	case 0x31:
 	case 0x51:
@@ -142,15 +147,9 @@ GSM_Error GSM_Phone_N6510::GetSMS2(GSM_SMSList *List, GSM_File *File)
 			j = j*7/8;
 			if (g != 0.0) j++;
 		}
-
 		SMS->UserData.append((const unsigned char *)File->Buffer.data()+i+1,j);
 		i+=j;
 		i+=11;
-
-//		if(File->Buffer.data()[start]!=0x71 && i<File->Buffer.size()) {
-//		} else {
-//			break;
-//		}
 		SMS->Name.append(NokiaGetUnicodeString(File->Buffer.data()+i),UnicodeLength(NokiaGetUnicodeString(File->Buffer.data()+i)));
 		if (UnicodeLength(NokiaGetUnicodeString(File->Buffer.data()+94)) != 0x00) {
 			break;
@@ -179,11 +178,22 @@ GSM_Error GSM_Phone_N6510::GetSMS2(GSM_SMSList *List, GSM_File *File)
 
 		j = File->Buffer.data()[i+11];
 		SMS->TPUDL = j;
-		SMS->UserData.append((const unsigned char *)File->Buffer.data()+i+12,j);
-
+		if (SMS->GetCoding() == SMS_Coding_Default_No_Compression) {
+			//we need to find, if part of byte was used or not
+			g = ((double)j*7/8) - (unsigned int)((j*7/8));
+			j = j*7/8;
+			if (g != 0.0) j++;
+		}
+		i+=12;
+		SMS->UserData.append((const unsigned char *)File->Buffer.data()+i,j);
+//		i+=j;
 		if (File->Buffer.data()[start]!=0x64) {
-			i+=j;
-			SMS->SetSMSCNumber(StringToUnicodeReturn((char *)(File->Buffer.data()+i+2)));
+			i+=SMS->TPUDL-12;
+			(*Debug)->Deb("%02x %02x %02x\n",File->Buffer.data()[i+2],File->Buffer.data()[i+3],File->Buffer.data()[i+4]);
+			(*Debug)->Deb("%i %i\n",i,File->Buffer.size());
+			if (i<File->Buffer.size()-10) {
+				SMS->SetSMSCNumber(StringToUnicodeReturn((char *)(File->Buffer.data()+i+2)));
+			}
 		}
 		break;
 	default:
@@ -220,19 +230,18 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder2(BOOLEAN start, GSM_SMSMMSF
 			}
 		}
 
-		if (!Found) {
-			FoldersCacheSubEntry = new GSM_FileFolderInfoListsSubEntry;			
-		}
-
-		SMSSubEntry = NULL;
-		if (FoldersCacheSubEntry->Info.GetNext(&SMSSubEntry)) {
+		if (Found) {
+			SMSCache2 = FoldersCacheSubEntry;
+			FoldersCacheSubEntry = NULL;
 			GetNextSMSFolder2.Code = GSM_ERR_NONE;
 			SMSSubEntry = NULL;
-			while (FoldersCacheSubEntry->Info.GetNext(&SMSSubEntry)) SMSListMax++;
+			while (SMSCache2->Info.GetNext(&SMSSubEntry)) SMSListMax++;
 		} else {
+			FoldersCacheSubEntry = new GSM_FileFolderInfoListsSubEntry;			
 			GetNextSMSFolder2.Code = GSM_ERR_FOLDER_MORE;
 			FoldersCacheSubEntry->Info.Info.SetID((wchar_t *)SMSFolder->ID.data());
 		}
+
 		SMSListPos = 0;
 		SMSSubEntry = NULL;
 	}
@@ -766,8 +775,8 @@ GSM_Error GSM_Phone_N6510::GetNextSMSMMSIDFromFolder1(BOOLEAN start, GSM_SMSMMSF
 
 GSM_Error GSM_Phone_N6510::DecodeSMSFrame1(GSM_SMSEntry *SMS, const unsigned char *buffer, int len, GSM_DateTime *SaveDateTime)
 {
-	int current,num,i;
-	BOOLEAN WasPhoneNum = FALSE;
+	int 		current,num,i;
+	BOOLEAN 	WasPhoneNum = FALSE;
 	
 	SMS->PhoneNumbers.ClearAll();
 	SMS->SMSCNumber.clear();
@@ -848,9 +857,9 @@ GSM_Error GSM_Phone_N6510::DecodeSMSFrame1(GSM_SMSEntry *SMS, const unsigned cha
 
 GSM_Error GSM_Phone_N6510::EncodeSMSFrameToBuffer1(GSM_SMSEntry *SMS, unsignedstring *Buffer)
 {
-	unsignedstring 	Temp,Temp2;
-	int 		num=0,num2=0;
-	unsigned char 	type,subtype;
+	unsignedstring 		Temp,Temp2;
+	int 			num=0,num2=0;
+	unsigned char 		type,subtype;
 	GSM_SMSNumbersSubEntry 	*Number;
 
 	switch (SMS->GetType()) {
