@@ -36,7 +36,9 @@ if(Ans("\x13",0x03,0x1A,ID_GetCalendar+ID3,&AS))   	return DCT34->ReplyGetNextCa
 if(Ans("\x13",0x03,0x32,ID_GetFirstCalendarPos+ID3,&AS))return DCT34->ReplyGetFirstCalPos1	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x3B,ID_GetCalendarInfo+ID3,&AS))    return DCT34->ReplyGetCalendarInfo1	(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x41,ID_AddCalendar+ID3,&AS))   	return DCT34->ReplyAddCalendar2		(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x13",0x03,0x66,ID_AddToDo+ID,&AS))   		return ReplyAddToDo2			(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x66,ID_AddCalendar+ID,&AS))   	return ReplyAddCalendar3		(msg,Debug,(unsigned char *)Struct);
+if(Ans("\x13",0x03,0x66,ID_AddNote+ID,&AS))   		return ReplyAddNote			(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x7E,ID_GetToDo+ID,&AS))    		return ReplyGetNextToDo2 		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x7E,ID_GetCalendar+ID,&AS))    	return ReplyGetNextCalendar3		(msg,Debug,(unsigned char *)Struct);
 if(Ans("\x13",0x03,0x7E,ID_GetNote+ID,&AS))    		return ReplyGetNextNote 		(msg,Debug,(unsigned char *)Struct);
@@ -281,6 +283,15 @@ GSM_Error GSM_Phone_N6510::SetPBK(GSM_PBKEntry *Entry)
 			Number--;
 			continue;
 		}
+		if (error.Code == GSM_ERR_FILE_EXIST) {
+			error.Code = GSM_ERR_NONE;
+//			error = DeletePBK(Entry);
+//			if (error.Code != GSM_ERR_NONE) return error;
+//			Buffer.clear();
+//			Buffer2.clear();
+//			continue;
+		}
+
 		return error;
 	}
 }
