@@ -15,10 +15,13 @@ typedef struct {
         GSM_Calendar_Type       NoteType;
 } GSM_Cal_Types;
 
+#define Feat_Series40_30 "-s40_30--todo6610-"
+
 class GSM_Phone_N6510:virtual public GSM_Phone
 {
 public:
         GSM_Phone_N6510(DebugInfo **Deb, GSM_Device **Dev, GSM_AllProtocols **Prot, GSM_AllPhones **Pho):GSM_Phone(Deb,Dev,Prot,Pho) {
+//RH-86 2610
         /*1*/   Info.push_back(GSM_Phone_Info("3100" , "RH-19"  ,  ""            ,"fbus", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("3120" , "RH-19"  ,  ""            ,"fbus", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("3100b", "RH-50"  ,  ""            ,"fbus", ""));
@@ -40,17 +43,21 @@ public:
         /*3FP2*/Info.push_back(GSM_Phone_Info("5200",  "RM-174" ,  "Nokia 5200"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6020" , "RM-30"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
         /*2*/   Info.push_back(GSM_Phone_Info("6020b", "RM-31"  ,  "Nokia 6020"  ,"fbus|irdaphonet", ""));
+        /*3FP2*/Info.push_back(GSM_Phone_Info("6085" , "RM-198" ,  "Nokia 6085"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30--todo6610-"));
         /*1*/   Info.push_back(GSM_Phone_Info("6100" , "NPL-2"  ,  "Nokia 6100"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", ""));
-        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30--todo6610-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6111" , "RM-82"  ,  "Nokia 6111"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3FP1*/Info.push_back(GSM_Phone_Info("6125" , "RM-178" ,  "Nokia 6125"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
         /*1*/   Info.push_back(GSM_Phone_Info("6170" , "RM-47"  ,  "Nokia 6170"  ,"fbus|irdaphonet|dku2phonet|dku2", ""));
         /*1*/   Info.push_back(GSM_Phone_Info("6220" , "RH-20"  ,  "Nokia 6220"  ,"fbus|irdaphonet|dku5fbus|dku5", "-file1only-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6230" , "RH-12"  ,  "Nokia 6230"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6230b", "RH-28"  ,  "Nokia 6230"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
         /*2*/   Info.push_back(GSM_Phone_Info("6230i", "RM-72"  ,  "Nokia 6230i" ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-file1--todo6610-"));
-        /*3*/   Info.push_back(GSM_Phone_Info("6233",  "RM-145" ,  "Nokia 6233"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
-        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
-        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
-        /*3FP2*/Info.push_back(GSM_Phone_Info("6300",  "RM-217" ,  "Nokia 6300"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", "-s40_30-"));
+        /*3*/   Info.push_back(GSM_Phone_Info("6233",  "RM-145" ,  "Nokia 6233"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3*/   Info.push_back(GSM_Phone_Info("6234",  "RM-123" ,  "Nokia 6234"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3*/   Info.push_back(GSM_Phone_Info("6270",  "RM-56"  ,  "Nokia 6270"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3*/   Info.push_back(GSM_Phone_Info("6288",  "RM-78"  ,  "Nokia 6288"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));//6280 ?
+        /*3FP2*/Info.push_back(GSM_Phone_Info("6300",  "RM-217" ,  "Nokia 6300"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
         /*0*/   Info.push_back(GSM_Phone_Info("6310",  "NPE-4"  ,  "Nokia 6310"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--nofile-"));
                 Info.push_back(GSM_Phone_Info("6310i", "NPL-1"  ,  "Nokia 6310i" ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dlr3fbus|dlr3", "-cal65--file1only-"));
                 Info.push_back(GSM_Phone_Info("6510" , "NPM-9"  ,  "Nokia 6510"  ,"fbus|irdaphonet", "-cal65-"));
@@ -67,6 +74,8 @@ public:
                 Info.push_back(GSM_Phone_Info("7250" , "NHL-4J" ,  "Nokia 7250"  ,"fbus|irdaphonet", ""));
                 Info.push_back(GSM_Phone_Info("7250i", "NHL-4JX",  "Nokia 7250i" ,"fbus|irdaphonet", ""));
                 Info.push_back(GSM_Phone_Info("7270" , "RM-8"   ,  "Nokia 7270"  ,"fbus|irdaphonet|dku2phonet|dku2", ""));
+        /*3*/   Info.push_back(GSM_Phone_Info("7370" , "RM-70"  ,  "Nokia 7370"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
+        /*3FP2*/Info.push_back(GSM_Phone_Info("7390" , "RM-140" ,  "Nokia 7390"  ,"fbus|irdaphonet|phonetblue|bluephonet|bluerfphonet|dku2phonet|dku2", Feat_Series40_30));
                 Info.push_back(GSM_Phone_Info("7600" , "NMM-3"  ,  "Nokia 7600"  ,"fbus|irdaphonet", ""));
                 Info.push_back(GSM_Phone_Info("8910" , "NHM-4"  ,  "Nokia 8910"  ,"fbus|irdaphonet", ""));
                 Info.push_back(GSM_Phone_Info("8910i", "NHM-4NX",  "Nokia 8910i" ,"fbus|irdaphonet", ""));
@@ -143,6 +152,7 @@ private:
 	//pbk
 	GSM_PBK_Features		PhonePBKFeatures;
 	GSM_PBK_Features		SIMPBKFeatures;
+//add: speed dial cache
         //calendar
         int                             CurrentCalendarNumber;
         GSM_Cal_Loc                     CalendarLocations;
