@@ -14,7 +14,7 @@ class GSM_Phone_NAUTO:virtual public GSM_Phone
 {
 public:
         GSM_Phone_NAUTO(DebugInfo **Deb, GSM_Device **Dev, GSM_AllProtocols **Prot, GSM_AllPhones **Pho):GSM_Phone(Deb,Dev,Prot,Pho) {
-		Info.push_back(GSM_Phone_Info("", "", "" ,"fbus|bluephonet|bluerfphonet|dku2phonet|dku2", ""));
+		Info.push_back(GSM_Phone_Info("", "", "" ,"fbus|bluephonet|bluerfphonet|phonetblue|dku2phonet|dku2", ""));
 
 		DCT34 = new GSM_Phone_NDCT34((*Phones)->GetID(),Deb,&(*Phones));
 
