@@ -159,8 +159,8 @@ void GSM_Phone_NDCT34::SetFrameID(char *Id)
 GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntry *Entry, int *Number, GSM_PBK_Features *Features)
 {
 	GSM_PBKSubEntry	 *SubEntry;
-	unsigned int	i;
-	int		 Type, Type2, MaxNum;
+	unsigned int	 i;
+	int		 Type, Type2, Type3, MaxNum;
 	int		 Name=1;//1-old name,2-last/first
 	unsignedstring	 TempBuffer, TempBuffer2;
 	BOOLEAN		 Avail;
@@ -190,7 +190,7 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 	SubEntry  = NULL;
 	while (Entry->GetNext(&SubEntry)) {
 		if (SubEntry->GetType()==PBK_Text_Name_First) {
-			Buff.push_back(' ');
+			if (Buff.size()!=0) Buff.push_back(' ');
 			Buff.append(SubEntry->GetText(),UnicodeLength(SubEntry->GetText()));
 		}
 	}
@@ -256,6 +256,7 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 	while (Entry->GetNext(&SubEntry)) {
 		TempBuffer.clear();
 		Type = 0x00;
+		Type3 = NPBK_NOTE;
 
 		switch (SubEntry->GetType()) {
 		case PBK_Text_Phone_General:
@@ -269,15 +270,71 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 		case PBK_Text_Phone_Fax:
 			if (Type == 0x00) Type = NPBK_NUMBER_FAX;
 			Type2 = NPBK_NUMBER;
+			Type3 = 0x00;
 			TempBuffer.push_back(Type);
 			TempBuffer.push_back(0x00);
-			TempBuffer.push_back(0x00); //voice tag in dct3
+			SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NONE);
+			if (SubEntry->VoiceTag != -1) {
+				SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NONE);
+				Avail = FALSE;
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == NPBK_VOICETAG_ID) {
+						Avail = TRUE;
+						break;
+					}
+				}
+				if (Avail) {
+					TempBuffer.push_back(0x00);
+				} else {
+					//check for 7110 and don't allow
+					SubEntry->VoiceTagSetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+					TempBuffer.push_back(SubEntry->VoiceTag); //voice tag in dct3
+				}
+			} else {
+				TempBuffer.push_back(0x00);
+			}
 			TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)/256);
 			TempBuffer.push_back(((UnicodeLength(SubEntry->GetText())+1)*2)%256);
 			NokiaSetUnicodeString(SubEntry->GetText(),&TempBuffer);
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
+			if (SubEntry->VoiceTag != -1 && Avail) {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+				Avail = FALSE;
+				for (i=0;i<Features->Types.size();i++) {
+					if (Features->Types.data()[i] == Type2) {
+						Avail = TRUE;
+						break;
+					}
+				}
+				if (!Avail) {
+					SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+					TempBuffer.clear();
+					break;
+				}
+				if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+				Buffer->push_back(Type2);
+				Buffer->push_back(0x00);
+				Buffer->push_back((TempBuffer.size()+6) / 256);
+				Buffer->push_back((TempBuffer.size()+6) % 256);
+				Buffer->push_back(++(*Number));
+				Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+				Buffer->push_back(0x00);
+				TempBuffer.clear();
+
+				if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+				Buffer->push_back(NPBK_VOICETAG_ID);
+				Buffer->push_back(0x00);
+				Buffer->push_back((2+6) / 256);
+				Buffer->push_back((2+6) % 256);
+				Buffer->push_back(0x00); //additional byte (other than in normal block)
+				Buffer->push_back((*Number)++);
+				Buffer->push_back(SubEntry->VoiceTag/256);//block byte 1
+				Buffer->push_back(SubEntry->VoiceTag%256);//block byte 2 - voice tag
+			}
+			if (SubEntry->SMSLists.length() != 0) {
+			}
 			break;		  
 		case PBK_Text_Postal:
 		case PBK_Text_Postal_Street:
@@ -318,13 +375,124 @@ GSM_Error GSM_Phone_NDCT34::EncodeEntryToPBK(unsignedstring *Buffer, GSM_PBKEntr
 			TempBuffer.push_back(0x00);
 			TempBuffer.push_back(0x00);
 			break;
+		case PBK_ID_Picture:
+			Type2 = NPBK_PICTURE_ID;
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == Type2) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (!Avail) {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+				TempBuffer.clear();
+				break;
+			}
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(SubEntry->LongValue / (256*256*256));
+			TempBuffer.push_back(SubEntry->LongValue / (256*256));
+			TempBuffer.push_back(SubEntry->LongValue / 256);
+			TempBuffer.push_back(SubEntry->LongValue % 256);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			TempBuffer.push_back(0x00);
+			Buffer->push_back(Type2);
+			Buffer->push_back(0x00);
+			Buffer->push_back((TempBuffer.size()+6) / 256);
+			Buffer->push_back((TempBuffer.size()+6) % 256);
+			Buffer->push_back(++(*Number));
+			Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+			Buffer->push_back(0x01);//difference from normal block
+			TempBuffer.clear();			
+			break;
+		case PBK_ID_Ringtone:
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == NPBK_RINGTONEFILE_ID) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (Avail) {
+				//FIXME: add
+				break;
+			}
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == NPBK_RINGTONE_ID) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (!Avail) {
+			}
+//			entry->Entries[i].AddError = ERR_NONE;
+//			string[0] = 0x00;
+//			string[1] = 0x00;
+//			string[2] = entry->Entries[i].Number;
+//			count += N71_65_PackPBKBlock(s, N7110_PBK_RINGTONE_ID, 3, block++, string, req + count);
+//			count --;
+//			req[count-5] = 8;
+			break;
+		case PBK_ID_Caller_Group:
+			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == NPBK_GROUP2_ID) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (Avail) {
+				if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
+				TempBuffer.push_back(0x00);
+				TempBuffer.push_back(0x00);
+				Buffer->push_back(NPBK_GROUP2_ID);
+				Buffer->push_back(0x00);
+				Buffer->push_back((TempBuffer.size()+6) / 256);
+				Buffer->push_back((TempBuffer.size()+6) % 256);
+				Buffer->push_back(++(*Number));
+				Buffer->append((const unsigned char*)TempBuffer.data(),TempBuffer.size());
+				Buffer->push_back(SubEntry->LongValue%256);//difference from normal block
+				TempBuffer.clear();			
+				break;
+			}
+			Type2 = NPBK_GROUP_ID;
+			Type3 = 0x00;
+			TempBuffer.push_back(SubEntry->LongValue%256);
+			TempBuffer.push_back(0x00);
+			break;
 		default:
 			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
 		}
 
 		if (TempBuffer.size() != 0) {
-			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
 			SubEntry->SetError = GSM_Return_Error(GSM_ERR_NONE);
+			Avail = FALSE;
+			for (i=0;i<Features->Types.size();i++) {
+				if (Features->Types.data()[i] == Type2) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			//we check, if we can convert it to other
+			if (!Avail && Type != 0x00) {
+				Type2 = Type3;
+				if (Features->Types.data()[i] == Type2) {
+					Avail = TRUE;
+					break;
+				}
+			}
+			if (!Avail) {
+				SubEntry->SetError = GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
+				continue;
+			}
+			if ((*Number)==MaxNum && MaxNum>0) return GSM_Return_Error(GSM_ERR_NONE);
 			Buffer->push_back(Type2);
 			Buffer->push_back(0x00);
 			Buffer->push_back((TempBuffer.size()+6) / 256);
@@ -444,6 +612,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	GSM_PBK_SubEntryType    Type;
 	GSM_PBKSubEntry 	*SubEntry,*PrevSubEntry=NULL;
 	BOOLEAN			Found,LastFirst=FALSE;
+	unsignedint		Nums;
 
 	(*Debug)->Deb("  %i blocks\n",Buffer[0]);
 	for (i=0;i<Buffer[0];i++) {
@@ -483,9 +652,16 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			}
 			(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+10)));
 			Entry->AddText(Type, NokiaGetUnicodeString(Buffer+Pos+10));
+			Nums.push_back(i);
 
 			/* ID for voice tags in DCT3 phones like 6210 */
 			if (Buffer[Pos+7] != 0) {
+				SubEntry = NULL;
+				while (Entry->GetNext(&SubEntry)) {
+					if (SubEntry->GetNext()==NULL) {
+						SubEntry->VoiceTag = Buffer[Pos+7];
+					}
+				}
 			}
 			break;
 		case NPBK_NOTE:
@@ -505,20 +681,20 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			}
 		case NPBK_NAME: // no break;
 			if (Type == PBK_Not_Assigned) {
-				(*Debug)->Deb("      Name");
+				(*Debug)->Deb("      Name\n");
 				break;
 			}
 		case NPBK_NAME_FIRST: // no break;
 			if (Type == PBK_Not_Assigned) {
 				LastFirst = TRUE;
 				Type = PBK_Text_Name_First;
-				(*Debug)->Deb("      First name");
+				(*Debug)->Deb("      First name\n");
 			}
 		case NPBK_NAME_LAST: // no break;
 			if (Type == PBK_Not_Assigned) {
 				LastFirst = TRUE;
 				Type = PBK_Text_Name_Last;
-				(*Debug)->Deb("      Last name");
+				(*Debug)->Deb("      Last name\n");
 			}
 		case NPBK_URL: // no break;
 			if (Type == PBK_Not_Assigned) {
@@ -537,6 +713,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			}
 			(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
 			Entry->AddText(Type, NokiaGetUnicodeString(Buffer+Pos+6));
+			Nums.push_back(i);
 			break;
 		case NPBK_POSTAL2:
 			Num = Buffer[Pos+7];
@@ -582,11 +759,13 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				}
 				(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
 				Entry->AddText(Type, NokiaGetUnicodeString(Buffer+Pos+6));
+				Nums.push_back(i);
 			}
 			break;
 		case NPBK_DATETIME:
 			(*Debug)->Deb("      DateTime\n");
 			Entry->AddDateTime(PBK_DateTime_Call_Length, *NokiaGetDT(Buffer+Pos+6));
+			Nums.push_back(i);
 			break;
 		case NPBK_CALL_LENGTH:
 			(*Debug)->Deb("      Call length\n");
@@ -595,7 +774,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			while (Entry->GetNext(&SubEntry) == TRUE) {
 				switch (SubEntry->GetType()) {
 				case PBK_DateTime_Call_Length:
-					if (SubEntry->Length != -1) {
+					if (SubEntry->CallLength != -1) {
 						Found = TRUE;
 						break;
 					}
@@ -603,24 +782,75 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 				}
 				if (Found) break;
 			}
-			PrevSubEntry->Length = Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11];
+			PrevSubEntry->CallLength = Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11];
 			break;
-		//todo
-		case NPBK_SMSLIST_ID:
-			(*Debug)->Deb("      SMS list ID\n");
+		case NPBK_GROUP_ID:
+			(*Debug)->Deb("      Caller group 1\n");
+			if (Buffer[Pos+5]!=0) {
+				Entry->AddLong(PBK_ID_Caller_Group, Buffer[Pos+5]);
+				Nums.push_back(i);
+			}
+			break;
+		case NPBK_GROUP2_ID:
+			(*Debug)->Deb("      Caller group 2\n");
+			Entry->AddLong(PBK_ID_Caller_Group, Buffer[Pos+7]);
+			Nums.push_back(i);
+			break;
+		case NPBK_VOICETAG_ID:
+			(*Debug)->Deb("      Voice tag ID %i for number %i\n",Buffer[Pos+6]*256+Buffer[Pos+7],Buffer[Pos+5]);
+			SubEntry = NULL;
+			j=0;
+			while (true) {
+				if (!Entry->GetNext(&SubEntry)) break;
+				switch (SubEntry->GetType()) {
+				case PBK_Text_Phone_General:
+				case PBK_Text_Phone_Mobile:
+				case PBK_Text_Phone_Home:
+				case PBK_Text_Phone_Work:
+				case PBK_Text_Phone_Fax:
+					j++;
+					break;
+				default:
+					break;
+				}
+				if (j==Buffer[Pos+5]) {
+					SubEntry->VoiceTag = Buffer[Pos+6]*256+Buffer[Pos+7];
+					break;
+				}
+			}
 			break;
 		case NPBK_PICTURE_ID:
 			(*Debug)->Deb("      Picture ID\n");
-			break;
-		case NPBK_VOICETAG_ID:
-			(*Debug)->Deb("      Voice tag ID\n");
-			break;
-		case NPBK_RINGTONEFILE_ID:
-			(*Debug)->Deb("      Ringtone file ID\n");
+			Entry->AddLong(PBK_ID_Picture, Buffer[Pos+8]*256*256*256+Buffer[Pos+9]*256*256+Buffer[Pos+10]*256+Buffer[Pos+11]);
+			Nums.push_back(i);
 			break;
 		case NPBK_RINGTONE_ID:
 			(*Debug)->Deb("      Ringtone ID\n");
+			Entry->AddLong(PBK_ID_Ringtone, Buffer[Pos+7]);
 			break;
+		case NPBK_RINGTONEFILE_ID:
+			(*Debug)->Deb("      Ringtone file ID (S40 3.0)\n");
+			Entry->AddLong(PBK_ID_Ringtone, Buffer[Pos+10]*256+Buffer[Pos+11]);
+			break;
+		case NPBK_SMSLIST_ID:
+//			smprintf(s, "Entry %i is assigned to SMS list %i\n",Block[5]-1,Block[9]);
+//			i = 0;
+//			while(entry->Entries[Block[5]-1].SMSList[i] != 0) i++;
+//			entry->Entries[Block[5]-1].SMSList[i+1] = 0;
+//			entry->Entries[Block[5]-1].SMSList[i]   = Block[9];
+
+			(*Debug)->Deb("      SMS list ID (3510)\n");
+			break;
+		case NPBK_PUSHTOTALK_SUBSC:
+			(*Debug)->Deb("      PTT subscription\n");
+			if (Buffer[Pos+5] == 0x01) {
+				Entry->AddBool(PBK_Bool_PTT_Subscribed, true);
+			} else {
+				Entry->AddBool(PBK_Bool_PTT_Subscribed, false);
+			}
+			Nums.push_back(i);
+			break;
+		//todo
 		case NPBK_SIM_SPEEDDIAL:
 			(*Debug)->Deb("      Speed dial\n");
 			break;
@@ -646,6 +876,8 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 		Pos+=Buffer[Pos+2]*256+Buffer[Pos+3];
 	}
 	if (!LastFirst) {
+		(*Debug)->Deb("  Searching for name\n");
+
 		Pos = 1;
 		for (i=0;i<Buffer[0];i++) {
 			(*Debug)->Deb("    Block length %i, type %02X\n",Buffer[Pos+2]*256+Buffer[Pos+3],Buffer[Pos]);
@@ -654,7 +886,8 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 			if (Buffer[Pos]==NPBK_NAME) {
 				(*Debug)->Deb("      Name");
 				(*Debug)->Deb(" \"%s\"\n",UnicodeToStringReturn(NokiaGetUnicodeString(Buffer+Pos+6)));
-				Entry->AddText(PBK_Text_Name_Last, NokiaGetUnicodeString(Buffer+Pos+6));
+				Entry->AddText(PBK_Text_Name, NokiaGetUnicodeString(Buffer+Pos+6));
+				break;
 			}
 			Pos+=Buffer[Pos+2]*256+Buffer[Pos+3];
 		}
@@ -662,7 +895,7 @@ GSM_Error GSM_Phone_NDCT34::DecodePBKToEntry(const unsigned char *Buffer, GSM_PB
 	SubEntry = NULL;
 	while (Entry->GetNext(&SubEntry) == TRUE) {
 		if (SubEntry->GetType()!=PBK_DateTime_Call_Length) continue;
-		if (SubEntry->Length == 0) SubEntry->Length=-1;
+		if (SubEntry->CallLength == 0) SubEntry->CallLength=-1;
 	}
 	return GSM_Return_Error(GSM_ERR_NONE);
 }
@@ -698,6 +931,12 @@ GSM_Error GSM_Phone_NDCT34::ReplySetPBK(GSM_Protocol_Message *msg, DebugInfo **D
 	if (msg->Buffer.data()[6] == 0x0F) {
 		(*Debug)->Deb("RECEIVED: error setting PBK entry");
 		switch (msg->Buffer.data()[10]) {
+		case 0x25:
+			(*Debug)->Deb(", you try to save into entry with caller group assigment in phone with caller groups standard 2 (like in 6230i)\n");
+			return GSM_Return_Error(GSM_ERR_FILE_EXIST);
+		case 0x29:
+//			smprintf(s, "no caller group with given number (6230i)\n");
+//			return ERR_MEMORY;
 		case 0x36:
 			(*Debug)->Deb(", too long text in subentry\n");
 			return GSM_Return_Error(GSM_ERR_NOT_SUPPORTED);
@@ -784,11 +1023,11 @@ GSM_Error GSM_Phone_NDCT34::GetCalendarInfo1()
 
 GSM_Error GSM_Phone_NDCT34::ReplyGetNextCalendar1(GSM_Protocol_Message *msg, DebugInfo **Debug, unsigned char *S)
 {
-	time_t			  timet;
-	struct tm		       tmstruct;
-	GSM_DateTime		    DT;
-	GSM_CalendarEntry	       *Calendar = (GSM_CalendarEntry *)S;
-	int			     Alarm = 0xffff; //no alarm
+	time_t			  	timet;
+	struct tm		       	tmstruct;
+	GSM_DateTime		    	DT;
+	GSM_CalendarEntry	       	*Calendar = (GSM_CalendarEntry *)S;
+	int			     	Alarm = 0xffff; //no alarm
 	GSM_Calendar_SubEntryType       AlarmType = Calendar_DateTime_ToneAlarm;
 
 	(*Debug)->Deb("RECEIVED: calendar entry method 1\n");
