@@ -18,7 +18,7 @@ GSM_Error GSM_Backup::FindTextFileChecksum(INI_File *File, char *checksum)
 	md5_state_t 		state;
 	md5_byte_t 		digest[16];
 	char 			hex_output[16*2 + 1];
-	int 			di;
+	unsigned int 		di;
 
 	StringToUnicode("Checksum",x);
 
@@ -108,26 +108,29 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 		while (PBKEntry->GetEntry()->GetNext(&PBKSubEntry) == TRUE) {
 			buff2[0] = 0;
 			switch (PBKSubEntry->GetType()) {
-			case PBK_Text_Phone_General: sprintf(buff2,"NumberGeneral"); 	break;
-			case PBK_Text_Phone_Mobile: sprintf(buff2,"NumberMobile"); 	break;
-			case PBK_Text_Phone_Home  : sprintf(buff2,"NumberHome"); 	break;
-			case PBK_Text_Phone_Work  : sprintf(buff2,"NumberWork"); 	break;
-			case PBK_Text_Phone_Fax   : sprintf(buff2,"NumberFax"); 	break;
-			case PBK_Text_Postal	  : sprintf(buff2,"Address"); 		break;
-			case PBK_Text_Postal_City : sprintf(buff2,"City"); 		break;
-			case PBK_Text_Postal_State: sprintf(buff2,"State"); 		break;
+			case PBK_Text_Phone_General  : sprintf(buff2,"NumberGeneral"); 	break;
+			case PBK_Text_Phone_Mobile   : sprintf(buff2,"NumberMobile"); 	break;
+			case PBK_Text_Phone_Home     : sprintf(buff2,"NumberHome"); 	break;
+			case PBK_Text_Phone_Work     : sprintf(buff2,"NumberWork"); 	break;
+			case PBK_Text_Phone_Fax      : sprintf(buff2,"NumberFax"); 	break;
+			case PBK_Text_Postal	     : sprintf(buff2,"Address"); 	break;
+			case PBK_Text_Postal_City    : sprintf(buff2,"City"); 		break;
+			case PBK_Text_Postal_State   : sprintf(buff2,"State"); 		break;
 			case PBK_Text_Postal_ZIP_Code: sprintf(buff2,"Zip"); 		break;
-			case PBK_Text_Postal_Country: sprintf(buff2,"Country"); 	break;
-			case PBK_Text_Postal_Street : sprintf(buff2,"Street"); 		break;
-			case PBK_Text_Email       : sprintf(buff2,"Email"); 		break;
-			case PBK_Text_URL         : sprintf(buff2,"URL"); 		break;
-			case PBK_Text_UserID	  : sprintf(buff2,"UserID"); 		break;
-			case PBK_Text_Note	  : sprintf(buff2,"Note"); 		break;
-			case PBK_Text_Name	  : sprintf(buff2,"Name"); 		break;
-			case PBK_Text_Name_Last	  : sprintf(buff2,"LastName"); 		break;
-			case PBK_Text_Name_First  : sprintf(buff2,"FirstName"); 	break;
-			case PBK_Text_PTT         : sprintf(buff2,"PTT"); 		break;
-			default			  : break;
+			case PBK_Text_Postal_Country : sprintf(buff2,"Country"); 	break;
+			case PBK_Text_Postal_Street  : sprintf(buff2,"Street"); 	break;
+			case PBK_Text_Email          : sprintf(buff2,"Email"); 		break;
+			case PBK_Text_URL            : sprintf(buff2,"URL"); 		break;
+			case PBK_Text_UserID	     : sprintf(buff2,"UserID"); 	break;
+			case PBK_Text_Note	     : sprintf(buff2,"Note"); 		break;
+			case PBK_Text_Name	     : sprintf(buff2,"Name"); 		break;
+			case PBK_Text_Name_Last	     : sprintf(buff2,"LastName"); 	break;
+			case PBK_Text_Name_First     : sprintf(buff2,"FirstName"); 	break;
+			case PBK_Text_PTT            : sprintf(buff2,"PTT"); 		break;
+			case PBK_Bool_PTT_Subscribed : sprintf(buff2,"PTTSubscribed"); 	break;
+			case PBK_ID_Caller_Group     : sprintf(buff2,"CallerGroup");	break;
+			case PBK_ID_Picture          : sprintf(buff2,"PictureID");	break;
+			default			     : break;
 			}
 			if (buff2[0] == 0) continue;
 			if (!Found) {
@@ -142,11 +145,43 @@ GSM_Error GSM_Backup::SavePbkToTextFile(FILE *file)
 			sprintf(buff,"Entry%02iType = ",Num2);
 			SaveTextFilePart(StringToUnicodeReturn(buff), file, FALSE);
 			SaveTextFilePart(StringToUnicodeReturn(buff2), file, TRUE);
-			sprintf(buff,"Entry%02iText = \"",Num2);
-			SaveTextFilePart(StringToUnicodeReturn(buff), file, FALSE);
-			SaveTextFilePart(PBKSubEntry->GetText(), file, FALSE);
-			sprintf(buff,"\"");
-			SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+
+			switch (PBKSubEntry->GetType()) {
+			case PBK_Bool_PTT_Subscribed:
+				if (PBKSubEntry->BoolValue) {
+					sprintf(buff,"Entry%02iValue = yes",Num2);
+				} else {
+					sprintf(buff,"Entry%02iValue = no",Num2);
+				}
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+				break;
+			case PBK_ID_Caller_Group:
+			case PBK_ID_Picture:
+				sprintf(buff,"Entry%02iNumber = %i",Num2,PBKSubEntry->LongValue);
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+				break;
+			default:
+				sprintf(buff,"Entry%02iText = \"",Num2);
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, FALSE);
+				SaveTextFilePart(PBKSubEntry->GetText(), file, FALSE);
+				sprintf(buff,"\"");
+				SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+			}
+
+			switch (PBKSubEntry->GetType()) {
+			case PBK_Text_Phone_General:
+			case PBK_Text_Phone_Mobile:
+			case PBK_Text_Phone_Home:
+			case PBK_Text_Phone_Work:
+			case PBK_Text_Phone_Fax:
+				if (PBKSubEntry->VoiceTag!=-1) {
+					sprintf(buff,"Entry%02iVoiceTag = %i",Num2,PBKSubEntry->VoiceTag);
+					SaveTextFilePart(StringToUnicodeReturn(buff), file, TRUE);
+				}
+				break;
+			default:
+				break;
+			}
 
 			Num2++;
 		}
@@ -413,7 +448,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 	while (File->GetNextSection(&Section)==TRUE) {
 		if (wcsncmp(x,(wchar_t *)Section->Name.data(),8) != 0) continue;
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Location"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Location"));
 		if (value == NULL) continue;
 
 		PBKEntry 		= new GSM_PBKEntry;
@@ -421,38 +456,68 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 		PBKEntry->Memory	= MEM_PHONE;
 		for (i=0;i<50;i++) {
 			sprintf(x2,"Entry%02iType",i);
-			value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
+			value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
 			if (value == NULL) continue;
 
 			PBKType = PBK_Not_Assigned;
 			if (!wcscmp(value,StringToUnicodeReturn("LastName"))) 		PBKType = PBK_Text_Name_Last;
-			if (!wcscmp(value,StringToUnicodeReturn("FirstName"))) 		PBKType = PBK_Text_Name_First;
-			if (!wcscmp(value,StringToUnicodeReturn("NumberMobile"))) 	PBKType = PBK_Text_Phone_Mobile;
-			if (!wcscmp(value,StringToUnicodeReturn("NumberHome"))) 	PBKType = PBK_Text_Phone_Home;
-			if (!wcscmp(value,StringToUnicodeReturn("NumberWork"))) 	PBKType = PBK_Text_Phone_Work;
-			if (!wcscmp(value,StringToUnicodeReturn("NumberFax"))) 		PBKType = PBK_Text_Phone_Fax;
-			if (!wcscmp(value,StringToUnicodeReturn("NumberGeneral"))) 	PBKType = PBK_Text_Phone_General;
-			if (!wcscmp(value,StringToUnicodeReturn("Address"))) 		PBKType = PBK_Text_Postal;
-			if (!wcscmp(value,StringToUnicodeReturn("City"))) 		PBKType = PBK_Text_Postal_City;
-			if (!wcscmp(value,StringToUnicodeReturn("State"))) 		PBKType = PBK_Text_Postal_State;
-			if (!wcscmp(value,StringToUnicodeReturn("Zip"))) 		PBKType = PBK_Text_Postal_ZIP_Code;
-			if (!wcscmp(value,StringToUnicodeReturn("Country"))) 		PBKType = PBK_Text_Postal_Country;
-			if (!wcscmp(value,StringToUnicodeReturn("Street"))) 		PBKType = PBK_Text_Postal_Street;
-			if (!wcscmp(value,StringToUnicodeReturn("Email"))) 		PBKType = PBK_Text_Email;
-			if (!wcscmp(value,StringToUnicodeReturn("URL"))) 		PBKType = PBK_Text_URL;
-			if (!wcscmp(value,StringToUnicodeReturn("UserID"))) 		PBKType = PBK_Text_UserID;
-			if (!wcscmp(value,StringToUnicodeReturn("Note"))) 		PBKType = PBK_Text_Note;
-			if (!wcscmp(value,StringToUnicodeReturn("PTT"))) 		PBKType = PBK_Text_PTT;
-			if (PBKType == PBK_Not_Assigned) continue;
+			else if (!wcscmp(value,StringToUnicodeReturn("FirstName"))) 	PBKType = PBK_Text_Name_First;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberMobile"))) 	PBKType = PBK_Text_Phone_Mobile;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberHome"))) 	PBKType = PBK_Text_Phone_Home;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberWork"))) 	PBKType = PBK_Text_Phone_Work;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberFax"))) 	PBKType = PBK_Text_Phone_Fax;
+			else if (!wcscmp(value,StringToUnicodeReturn("NumberGeneral"))) PBKType = PBK_Text_Phone_General;
+			else if (!wcscmp(value,StringToUnicodeReturn("Address"))) 	PBKType = PBK_Text_Postal;
+			else if (!wcscmp(value,StringToUnicodeReturn("City"))) 		PBKType = PBK_Text_Postal_City;
+			else if (!wcscmp(value,StringToUnicodeReturn("State"))) 	PBKType = PBK_Text_Postal_State;
+			else if (!wcscmp(value,StringToUnicodeReturn("Zip"))) 		PBKType = PBK_Text_Postal_ZIP_Code;
+			else if (!wcscmp(value,StringToUnicodeReturn("Country"))) 	PBKType = PBK_Text_Postal_Country;
+			else if (!wcscmp(value,StringToUnicodeReturn("Street"))) 	PBKType = PBK_Text_Postal_Street;
+			else if (!wcscmp(value,StringToUnicodeReturn("Email"))) 	PBKType = PBK_Text_Email;
+			else if (!wcscmp(value,StringToUnicodeReturn("URL"))) 		PBKType = PBK_Text_URL;
+			else if (!wcscmp(value,StringToUnicodeReturn("UserID"))) 	PBKType = PBK_Text_UserID;
+			else if (!wcscmp(value,StringToUnicodeReturn("Note"))) 		PBKType = PBK_Text_Note;
+			else if (!wcscmp(value,StringToUnicodeReturn("PTT"))) 		PBKType = PBK_Text_PTT;
+			if (PBKType == PBK_Not_Assigned) {
+				if (!wcscmp(value,StringToUnicodeReturn("CallerGroup"))) 	PBKType = PBK_ID_Caller_Group;
+				else if (!wcscmp(value,StringToUnicodeReturn("PictureID"))) 	PBKType = PBK_ID_Picture;
+
+				if (PBKType == PBK_Not_Assigned) continue;
+
+				sprintf(x2,"Entry%02iNumber",i);
+				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
+				if (value == NULL) continue;
+
+				PBKEntry->AddLong(PBKType,atol(UnicodeToStringReturn(value)));
+
+				continue;
+			}
 
 			sprintf(x2,"Entry%02iText",i);
-			value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
+			value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
 			if (value == NULL) continue;
 			if (UnicodeLength(value)==0) continue;
 
 			value[UnicodeLength(value)-1] = 0;
 			ReadTextFilePart(value+1, &Txt);
 			PBKEntry->AddText(PBKType,(wchar_t *)Txt.data());
+
+			if (PBKType == PBK_Text_Phone_Mobile ||
+			    PBKType == PBK_Text_Phone_Home ||
+			    PBKType == PBK_Text_Phone_Work ||
+			    PBKType == PBK_Text_Phone_Fax ||
+			    PBKType == PBK_Text_Phone_General) {
+				sprintf(x2,"Entry%02iVoiceTag",i);
+				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
+				if (value != NULL) {
+					SubEntry = NULL;
+					while (PBKEntry->GetNext(&SubEntry)) {
+						if (SubEntry->GetNext() == NULL) {
+							SubEntry->VoiceTag = atol(UnicodeToStringReturn(value));
+						}
+					}
+				}
+			}
 		}
 		Found = FALSE;
 		SubEntry = NULL;
@@ -469,7 +534,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 		if (!Found) {
 			for (i=0;i<50;i++) {
 				sprintf(x2,"Entry%02iType",i);
-				value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
+				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
 				if (value == NULL) continue;
 
 				PBKType = PBK_Not_Assigned;
@@ -477,7 +542,7 @@ GSM_Error GSM_Backup::ReadPbkFromTextFile(INI_File *File)
 				if (PBKType == PBK_Not_Assigned) continue;
 
 				sprintf(x2,"Entry%02iText",i);
-				value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn(x2));
+				value = File->GetValueInSection(Section,StringToUnicodeReturn(x2));
 				if (value == NULL) continue;
 				if (UnicodeLength(value)==0) continue;
 
@@ -503,15 +568,15 @@ GSM_Error GSM_Backup::ReadCalendarFromTextFile(INI_File *File)
 	while (File->GetNextSection(&Section)==TRUE) {
 		if (wcsncmp(x,(wchar_t *)Section->Name.data(),8) != 0) continue;
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Type"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Type"));
 		if (value == NULL) continue;
 
 		CalType = Calendar_Type_Not_Assigned;
-		if (!wcscmp(value,StringToUnicodeReturn("Meeting"))) 	CalType = Calendar_Type_Meeting;
-		if (!wcscmp(value,StringToUnicodeReturn("Memo"))) 	CalType = Calendar_Type_Memo;
-		if (!wcscmp(value,StringToUnicodeReturn("Call"))) 	CalType = Calendar_Type_Call;
-		if (!wcscmp(value,StringToUnicodeReturn("Birthday"))) 	CalType = Calendar_Type_Birthday;
-		if (!wcscmp(value,StringToUnicodeReturn("Reminder"))) 	CalType = Calendar_Type_Reminder;
+		if (!wcscmp(value,StringToUnicodeReturn("Meeting"))) 		CalType = Calendar_Type_Meeting;
+		else if (!wcscmp(value,StringToUnicodeReturn("Memo"))) 		CalType = Calendar_Type_Memo;
+		else if (!wcscmp(value,StringToUnicodeReturn("Call"))) 		CalType = Calendar_Type_Call;
+		else if (!wcscmp(value,StringToUnicodeReturn("Birthday"))) 	CalType = Calendar_Type_Birthday;
+		else if (!wcscmp(value,StringToUnicodeReturn("Reminder"))) 	CalType = Calendar_Type_Reminder;
 		if (CalType == Calendar_Type_Not_Assigned) continue;
 
 		CalEntry = new GSM_CalendarEntry;
@@ -519,49 +584,49 @@ GSM_Error GSM_Backup::ReadCalendarFromTextFile(INI_File *File)
 
 		// ----------------------- times ------------------------------
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("StartTime"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("StartTime"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			CalEntry->AddDateTime(Calendar_DateTime_Start, DT);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("StopTime"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("StopTime"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			CalEntry->AddDateTime(Calendar_DateTime_End, DT);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("AlarmType"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("AlarmType"));
 		if (value != NULL && !strcmp(UnicodeToStringReturn(value),"Silent")) {
-			value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Alarm"));
+			value = File->GetValueInSection(Section,StringToUnicodeReturn("Alarm"));
 			if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 				CalEntry->AddDateTime(Calendar_DateTime_SilentAlarm, DT);
 			}
 		} else {
-			value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Alarm"));
+			value = File->GetValueInSection(Section,StringToUnicodeReturn("Alarm"));
 			if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 				CalEntry->AddDateTime(Calendar_DateTime_ToneAlarm, DT);
 			}
 		}
 		
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("RepeatStopDate"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("RepeatStopDate"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			CalEntry->AddDateTime(Calendar_DateTime_End_Repeat, DT);
 		}
 
 		// ----------------------- texts ------------------------------
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("EventLocation"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("EventLocation"));
 		if (value != NULL && UnicodeLength(value)!=0) {
 			value[UnicodeLength(value)-1] = 0;
 			CalEntry->AddText(Calendar_Text_Location, value+1);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Text"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Text"));
 		if (value != NULL && UnicodeLength(value)!=0) {
 			value[UnicodeLength(value)-1] = 0;
 			CalEntry->AddText(Calendar_Text_Text, value+1);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Phone"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Phone"));
 		if (value != NULL && UnicodeLength(value)!=0) {
 			value[UnicodeLength(value)-1] = 0;
 			CalEntry->AddText(Calendar_Text_Phone, value+1);
@@ -569,22 +634,22 @@ GSM_Error GSM_Backup::ReadCalendarFromTextFile(INI_File *File)
 
 		// ------------------------ int -------------------------------
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("RepeatDayOfWeek"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("RepeatDayOfWeek"));
 		if (value != NULL) {
 			CalEntry->AddInt(Calendar_Int_Repeat_DayOfWeek, atoi(UnicodeToStringReturn(value)));
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("RepeatDay"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("RepeatDay"));
 		if (value != NULL) {
 			CalEntry->AddInt(Calendar_Int_Repeat_Day, atoi(UnicodeToStringReturn(value)));
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("RepeatMonth"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("RepeatMonth"));
 		if (value != NULL) {
 			CalEntry->AddInt(Calendar_Int_Repeat_Month, atoi(UnicodeToStringReturn(value)));
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("RepeatFrequency"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("RepeatFrequency"));
 		if (value != NULL) {
 			CalEntry->AddInt(Calendar_Int_Repeat_Frequency, atoi(UnicodeToStringReturn(value)));
 		}
@@ -606,14 +671,14 @@ GSM_Error GSM_Backup::ReadNoteFromTextFile(INI_File *File)
 	while (File->GetNextSection(&Section)==TRUE) {
 		if (wcsncmp(x,(wchar_t *)Section->Name.data(),4) != 0) continue;
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Text"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Text"));
 		if (value == NULL) continue;
 
 		ReadTextFilePart(value+1, &Txt);
 		NoteEntry = new GSM_NoteEntry;
 		NoteEntry->Text.append(Txt.data(),Txt.size()-1);
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Location"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Location"));
 		if (value == NULL) continue;
 		NoteEntry->Location = atoi(UnicodeToStringReturn(value));
 
@@ -637,13 +702,13 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 	while (File->GetNextSection(&Section)==TRUE) {
 		if (wcsncmp(x,(wchar_t *)Section->Name.data(),4) != 0) continue;
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Location"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Location"));
 		if (value == NULL) continue;
 
 		ToDoEntry = new GSM_ToDoEntry;
 		ToDoEntry->Location = atoi(UnicodeToStringReturn(value));
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Text"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Text"));
 		if (value != NULL) {
 			ReadTextFilePart(value+1, &Txt);
 			ToDoSubEntry = new GSM_ToDoSubEntry;
@@ -652,12 +717,12 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 			ToDoEntry->AddSubEntry(ToDoSubEntry);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Priority"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Priority"));
 		if (value != NULL) {
 			Priority = GSM_Priority_Not_Assigned;
-			if (!wcscmp(value,StringToUnicodeReturn("High"))) 	Priority = GSM_Priority_High;
-			if (!wcscmp(value,StringToUnicodeReturn("Medium"))) 	Priority = GSM_Priority_Medium;
-			if (!wcscmp(value,StringToUnicodeReturn("Low"))) 	Priority = GSM_Priority_Low;
+			if (!wcscmp(value,StringToUnicodeReturn("High"))) 		Priority = GSM_Priority_High;
+			else if (!wcscmp(value,StringToUnicodeReturn("Medium"))) 	Priority = GSM_Priority_Medium;
+			else if (!wcscmp(value,StringToUnicodeReturn("Low"))) 		Priority = GSM_Priority_Low;
 			if (Priority != GSM_Priority_Not_Assigned) {
 				ToDoSubEntry = new GSM_ToDoSubEntry;
 				ToDoSubEntry->Priority = Priority;
@@ -666,7 +731,7 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 			}
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Completed"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Completed"));
 		if (value != NULL && !wcscmp(value,StringToUnicodeReturn("yes"))) {
 			ToDoSubEntry = new GSM_ToDoSubEntry;
 			ToDoSubEntry->BoolValue = TRUE;
@@ -674,7 +739,7 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 			ToDoEntry->AddSubEntry(ToDoSubEntry);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("DueTime"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("DueTime"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			ToDoSubEntry = new GSM_ToDoSubEntry;
 			memcpy(&ToDoSubEntry->DT,&DT,sizeof(GSM_DateTime));
@@ -682,7 +747,7 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 			ToDoEntry->AddSubEntry(ToDoSubEntry);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("Alarm"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("Alarm"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			ToDoSubEntry = new GSM_ToDoSubEntry;
 			memcpy(&ToDoSubEntry->DT,&DT,sizeof(GSM_DateTime));
@@ -690,7 +755,7 @@ GSM_Error GSM_Backup::ReadToDoFromTextFile(INI_File *File)
 			ToDoEntry->AddSubEntry(ToDoSubEntry);
 		}
 
-		value = File->GetValue((wchar_t *)Section->Name.data(),StringToUnicodeReturn("SilentAlarm"));
+		value = File->GetValueInSection(Section,StringToUnicodeReturn("SilentAlarm"));
 		if (value != NULL && ReadVCalendarDateTime(UnicodeToStringReturn(value), &DT)==TRUE) {
 			ToDoSubEntry = new GSM_ToDoSubEntry;
 			memcpy(&ToDoSubEntry->DT,&DT,sizeof(GSM_DateTime));
