@@ -6,6 +6,7 @@
 void GSM_Backup::GetFileFunctions(GSM_Backup_FileFormatNum Num, GSM_Backup_FileFormatFunctions *Func)
 {
 	if (Num == Backup_Gammu) {
+		Func->PhonePBKCallers = TRUE;
 		Func->PhonePBKPointers = TRUE;
 		Func->PhonePBK 	= TRUE;
 		Func->SIMPBK 	= TRUE;
@@ -599,6 +600,112 @@ void GSM_Backup::Add_SMS0(GSM_Backup_SMSEntry **Start, GSM_SMSList *En)
 	}
 }
 
+void GSM_Backup::DeletePointersFromPBK()
+{
+	GSM_Backup_PBKEntry	*PBKEntry=NULL,*PBK2=NULL,*PBKEntry2,*Entry2;
+	GSM_PBKSubEntry 	*SubEntry;
+	GSM_PBKEntry 		*En;
+
+	while (GetNext_PBK(&PBKEntry)) {
+		SubEntry = NULL;
+		En = new GSM_PBKEntry;
+		while (PBKEntry->GetEntry()->GetNext(&SubEntry)) {
+			switch (SubEntry->GetType()) {
+			case PBK_DateTime_Call_Length:
+				break; //not required for this memory
+			case PBK_ID_Caller_Group:
+				En->AddLong(SubEntry->GetType(),SubEntry->LongValue);
+				break;
+			case PBK_ID_Picture:
+			case PBK_ID_Ringtone:
+				break; //we delete them
+			case PBK_Bool_PTT_Subscribed:
+				En->AddBool(SubEntry->GetType(),SubEntry->BoolValue);
+				break;
+			default:
+				//we delete voicetag from number too
+				En->AddText(SubEntry->GetType(), SubEntry->GetText());
+				break;
+			}
+		}
+
+		En->Location = PBKEntry->GetEntry()->Location;
+		En->Memory = PBKEntry->GetEntry()->Memory;
+
+		PBKEntry2 = new GSM_Backup_PBKEntry;
+		PBKEntry2->SetEntry(En);
+
+		if (PBK2 == NULL) {
+			PBK2 = PBKEntry2;
+		} else {
+			Entry2 = PBK2;
+			while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+			Entry2->SetNext(PBKEntry2);
+		}
+	}
+
+	delete PBK;
+
+	PBK = PBK2;
+}
+
+void GSM_Backup::DeleteCallerFromPBK()
+{
+	GSM_Backup_PBKEntry	*PBKEntry=NULL,*PBK2=NULL,*PBKEntry2,*Entry2;
+	GSM_PBKSubEntry 	*SubEntry,*SubEntry2;
+	GSM_PBKEntry 		*En;
+
+	while (GetNext_PBK(&PBKEntry)) {
+		SubEntry = NULL;
+		En = new GSM_PBKEntry;
+		while (PBKEntry->GetEntry()->GetNext(&SubEntry)) {
+			switch (SubEntry->GetType()) {
+			case PBK_DateTime_Call_Length:
+				break; //not required for this memory
+			case PBK_ID_Caller_Group:
+				//we delete it
+				break;
+			case PBK_ID_Picture:
+			case PBK_ID_Ringtone:
+				En->AddLong(SubEntry->GetType(),SubEntry->LongValue);
+				break;
+			case PBK_Bool_PTT_Subscribed:
+				En->AddBool(SubEntry->GetType(),SubEntry->BoolValue);
+				break;
+			default:
+				En->AddText(SubEntry->GetType(), SubEntry->GetText());
+				if (SubEntry->VoiceTag!=-1) {
+					SubEntry2 = NULL;
+					while (En->GetNext(&SubEntry2)) {
+						if (SubEntry2->GetNext()==NULL) {
+							SubEntry2->VoiceTag = SubEntry->VoiceTag;
+						}
+					}
+				}
+				break;
+			}
+		}
+
+		En->Location = PBKEntry->GetEntry()->Location;
+		En->Memory = PBKEntry->GetEntry()->Memory;
+
+		PBKEntry2 = new GSM_Backup_PBKEntry;
+		PBKEntry2->SetEntry(En);
+
+		if (PBK2 == NULL) {
+			PBK2 = PBKEntry2;
+		} else {
+			Entry2 = PBK2;
+			while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+			Entry2->SetNext(PBKEntry2);
+		}
+	}
+
+	delete PBK;
+
+	PBK = PBK2;
+}
+
 /* ------------------------------------------------------------------------- */
 
 GSM_Backup_PBKEntry::GSM_Backup_PBKEntry()
