@@ -11,7 +11,10 @@ wchar_t	*GSM_PBKSubEntry::GetText()
 
 GSM_PBKSubEntry::GSM_PBKSubEntry()
 {
-	Length = -1;
+	SMSLists.clear();
+	BoolValue = false;
+	CallLength = -1;
+	VoiceTag = -1;
 	Type   = PBK_Not_Assigned;
 	Text   = NULL;
 	Next   = NULL;
@@ -28,6 +31,24 @@ GSM_PBK_SubEntryType GSM_PBKSubEntry::GetType()
 	return Type;
 }
 
+GSM_Error GSM_PBKSubEntry::SetToLong(GSM_PBK_SubEntryType Typ, long long2)
+{
+	Type = Typ;
+
+	LongValue = long2;
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_PBKSubEntry::SetToBool(GSM_PBK_SubEntryType Typ, bool bool2)
+{
+	Type = Typ;
+
+	BoolValue = bool2;
+
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
 GSM_Error GSM_PBKSubEntry::SetToText(GSM_PBK_SubEntryType Typ, wchar_t *Txt)
 {
 	int len = (UnicodeLength(Txt)+1)*sizeof(wchar_t);
@@ -102,6 +123,44 @@ GSM_Error GSM_PBKEntry::AddText(GSM_PBK_SubEntryType Typ, wchar_t *Txt)
 		return error;
 	}
 
+	if (Entries == NULL) {
+		Entries = Entry;
+	} else {
+		Entry2 = Entries;
+		while (Entry2->GetNext()!=NULL) {
+			Entry2 = Entry2->GetNext();
+		}
+		Entry2->SetNext(Entry);
+	}
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_PBKEntry::AddLong(GSM_PBK_SubEntryType Typ, long long2)
+{
+	GSM_PBKSubEntry *Entry,*Entry2;
+	GSM_Error	error;
+
+	Entry = new GSM_PBKSubEntry;
+	Entry->SetToLong(Typ, long2);
+
+	if (Entries == NULL) {
+		Entries = Entry;
+	} else {
+		Entry2 = Entries;
+		while (Entry2->GetNext()!=NULL) Entry2 = Entry2->GetNext();
+		Entry2->SetNext(Entry);
+	}
+	return GSM_Return_Error(GSM_ERR_NONE);
+}
+
+GSM_Error GSM_PBKEntry::AddBool(GSM_PBK_SubEntryType Typ, bool bool2)
+{
+	GSM_PBKSubEntry *Entry,*Entry2;
+	GSM_Error	error;
+
+	Entry = new GSM_PBKSubEntry;
+	Entry->SetToBool(Typ, bool2);
+
 	if (Entries == NULL) {
 		Entries = Entry;
 	} else {
