@@ -33,14 +33,10 @@ typedef enum {
 	PBK_Text_Name_First,
 	PBK_Text_PTT,
 	PBK_DateTime_Call_Length,
-
-	//not supported yet
-	PBK_ID_SMSList,
+	PBK_ID_Caller_Group,
 	PBK_ID_Picture,
-	PBK_ID_VoiceTag,
-	PBK_ID_RingtoneFile,
 	PBK_ID_Ringtone,
-	PBK_ID_SpeedDial
+	PBK_Bool_PTT_Subscribed
 } GSM_PBK_SubEntryType;
 
 class GSM_PBKSubEntry
@@ -51,13 +47,21 @@ public:
 	~GSM_PBKSubEntry();
 
 	GSM_Error		SetError;
-
 	GSM_PBK_SubEntryType 	GetType();
 	GSM_Error 		SetToText(GSM_PBK_SubEntryType Typ, wchar_t *Txt);
 	wchar_t			*GetText();
 	GSM_Error 		SetToDateTime(GSM_PBK_SubEntryType Typ, GSM_DateTime DT2);
 	GSM_DateTime		*GetDateTime();
-	long			Length;
+	GSM_Error 		SetToLong(GSM_PBK_SubEntryType Typ, long long2);
+	GSM_Error 		SetToBool(GSM_PBK_SubEntryType Typ, bool bool2);
+	long			LongValue;
+	bool			BoolValue;
+
+	long			VoiceTag;
+	GSM_Error		VoiceTagSetError;
+	long			CallLength;
+	unsignedint		SMSLists;
+	GSM_Error		SMSListsSetError;
 
 	GSM_PBKSubEntry		*GetNext();
 private:
@@ -82,6 +86,8 @@ public:
 	BOOLEAN 		GetNext(GSM_PBKSubEntry **En);
 	GSM_Error	 	AddText(GSM_PBK_SubEntryType Typ, wchar_t *Txt);
 	GSM_Error	 	AddDateTime(GSM_PBK_SubEntryType Typ, GSM_DateTime DT2);
+	GSM_Error	 	AddLong(GSM_PBK_SubEntryType Typ, long long2);
+	GSM_Error	 	AddBool(GSM_PBK_SubEntryType Typ, bool bool2);
 private:
 	GSM_PBKSubEntry		*Entries;
 };
