@@ -574,8 +574,8 @@ void GetMemory(GSM_StateMachine *s, GSM_GPlusConfig *CFG, int argc, char *argv[]
 					SubEntry->GetDateTime()->Year);
 				break;
 			}
-			if (SubEntry->Length != -1) {
-				printf(" (length %i:%i:%i)",SubEntry->Length/(60*60),SubEntry->Length/60,SubEntry->Length%60);
+			if (SubEntry->CallLength != -1) {
+				printf(" (length %i:%i:%i)",SubEntry->CallLength/(60*60),SubEntry->CallLength/60,SubEntry->CallLength%60);
 			}
 			printf("\n");
 		}
@@ -739,7 +739,7 @@ int main2(int argc, char *argv[])
 	} else if (argc > 1 && StringCaseCmp(argv[1],"textall",-1)) {
 		startarg++;
 	}
-	s.ReadCfg(&CFGFile);
+	s.ReadCfg(1,&CFGFile);
 
 	if (CFGFile.RSSLevel[0]!=0) {
 		CheckRSS(&Stable, &Test);
