@@ -118,28 +118,23 @@ void MainFrm::Mnunewphone1003Click(wxCommandEvent& event)
     GSM_GPlusConfig     CFG;
     GSM_DateTime        DT;
 
-    dialog = new CfgDlg(this,-1,"About...",wxDefaultPosition,wxDefaultSize,CfgDlg_STYLE);
-
     s = new GSM_StateMachine(NULL,"",false);
-    s->ReadCfg(&CFG);
-    
-    dialog->SetConfig(&CFG,s);
+
+    dialog = new CfgDlg(&CFG,s,this,-1,"About...",wxDefaultPosition,wxDefaultSize,CfgDlg_STYLE);
 
     while (true) {
         if (dialog->ShowModal()!= wxID_OK) {
+            delete(s);
             dialog->Destroy();
             return;
         }
         
-        s->SaveCfg(&CFG);
-        
         delete (s);
         if (!strcmp(CFG.LogLevel,"nothing")) {
             s = new GSM_StateMachine(NULL,"",false);
         } else {
             s = new GSM_StateMachine(NULL,CFG.LogFile,true);
         }
-        s->ReadCfg(&CFG);
         
         error = s->Open(&CFG);
         if (error.Code == GSM_ERR_NONE) break;
@@ -268,8 +263,8 @@ void MainFrm::Mnuopenbackupfile1010Click(wxCommandEvent& event)
 void MainFrm::Mnucheckforupdate1011Click(wxCommandEvent& event)
 {
 	unsignedstring Stable,Test;
-	char buff[200],buffer[200];
-	GSM_Error error;
+	char           buff[200],buffer[200];
+	GSM_Error      error;
 
     error = CheckRSS(&Stable, &Test);
     if (error.Code != GSM_ERR_NONE) {
